import React, { useState, useEffect } from 'react';
import { Menu, X, Bot } from 'lucide-react';
import { useLocation, Link, useNavigate } from 'react-router-dom';

const scrollToElement = (elementId: string) => {
  const element = document.getElementById(elementId);
  if (element) {
    const yOffset = -100; // Offset for the fixed navbar
    const y = element.getBoundingClientRect().top + window.pageYOffset + yOffset;
    window.scrollTo({ top: y, behavior: 'smooth' });
  }
};

const Navbar: React.FC = () => {
  const [isOpen, setIsOpen] = useState(false);
  const [isScrolled, setIsScrolled] = useState(false);
  const location = useLocation();
  const navigate = useNavigate();
  
  const isMainPage = location.pathname === '/';
  
  const handleNavigation = (sectionId: string) => {
    if (isMainPage) {
      scrollToElement(sectionId);
      setIsOpen(false);
    } else {
      navigate('/', { state: { scrollTo: sectionId } });
      setTimeout(() => {
        scrollToElement(sectionId);
      }, 100);
      setIsOpen(false);
    }
  };

  useEffect(() => {
    if (location.state?.scrollTo) {
      const sectionId = location.state.scrollTo;
      setTimeout(() => {
        scrollToElement(sectionId);
      }, 100);
      window.history.replaceState({}, '');
    }
  }, [location]);

  useEffect(() => {
    const handleScroll = () => {
      if (window.scrollY > 10) {
        setIsScrolled(true);
      } else {
        setIsScrolled(false);
      }
    };

    window.addEventListener('scroll', handleScroll);
    return () => {
      window.removeEventListener('scroll', handleScroll);
    };
  }, []);

  return (
    <nav 
      className={`fixed w-full z-50 transition-all duration-300 ${
        isScrolled ? 'py-2' : 'py-4'
      }`}
    >
      <div className="container mx-auto px-4">
        <div className="mx-auto max-w-6xl bg-gray-900/40 backdrop-blur-md rounded-full border border-white/20 shadow-lg px-6 py-2">
          <div className="flex justify-between items-center">
            <div className="flex items-center">
              <Link to="/" className="flex items-center group" aria-label="ZenTalk Home">
                <div className="relative">
                  <div className="relative w-10 h-10 mr-2">
                    <div className="absolute inset-0 bg-gradient-to-r from-blue-500/20 to-teal-500/20 rounded-lg blur group-hover:blur-md transition-all duration-500"></div>
                    <div className="absolute inset-0 bg-gradient-to-br from-blue-500 to-teal-500 rounded-lg opacity-90"></div>
                    <div className="absolute inset-0 flex items-center justify-center">
                      <div className="w-6 h-[2px] bg-white/25 rounded-full absolute transform translate-y-[6px]"></div>
                      <div className="w-6 h-[2px] bg-white/50 rounded-full absolute transform translate-y-[2px]"></div>
                      <div className="w-6 h-[2px] bg-white/75 rounded-full absolute transform translate-y-[-2px]"></div>
                      <div className="w-6 h-[2px] bg-white rounded-full absolute transform translate-y-[-6px]"></div>
                    </div>
                  </div>
                </div>
                <span className="text-xl font-bold bg-gradient-to-r from-blue-400 to-teal-400 bg-clip-text text-transparent">ZenTalk</span>
              </Link>
            </div>

            {/* Desktop Menu */}
            <nav className="hidden md:flex space-x-8" aria-label="Main navigation">
              <Link to="/ai-automation" className="text-white/90 hover:text-blue-400 font-medium transition-colors">
                Mindful AI
              </Link>
              <Link to="/smart-chatbots" className="text-white/90 hover:text-blue-400 font-medium transition-colors">
                Zen Chatbots
              </Link>
              <button 
                onClick={() => handleNavigation('how-it-works')}
                className="text-white/90 hover:text-blue-400 font-medium transition-colors"
              >
                How It Works
              </button>
              <button 
                onClick={() => handleNavigation('benefits')}
                className="text-white/90 hover:text-blue-400 font-medium transition-colors"
              >
                Benefits
              </button>
            </nav>

            {/* CTA Button */}
            <a 
              onClick={() => handleNavigation('contact')}
              className="hidden md:block bg-blue-500 hover:bg-blue-600 text-white px-6 py-2.5 rounded-full transition-all duration-300 font-medium hover:shadow-[0_0_20px_rgba(59,130,246,0.5)] hover:scale-105 cursor-pointer"
              aria-label="Book a consultation"
            >
              Book a Consultation
            </a>

            {/* Mobile Menu Button */}
            <button 
              className="md:hidden text-white"
              aria-label="Toggle mobile menu"
              aria-expanded={isOpen}
              onClick={() => setIsOpen(!isOpen)}
            >
              {isOpen ? <X size={24} /> : <Menu size={24} />}
            </button>
          </div>

          {/* Mobile Menu */}
          <div 
            className={`md:hidden absolute w-full transition-all duration-300 ease-in-out ${
              isOpen ? 'max-h-64 opacity-100' : 'max-h-0 opacity-0 overflow-hidden'
            }`}
            role="navigation"
            aria-label="Mobile navigation"
          >
            <div className="mx-4 mt-2 bg-gray-900/90 backdrop-blur-md rounded-2xl p-4 shadow-lg border border-white/20">
              <Link 
                to="/ai-automation" 
                className="block text-white/90 hover:text-blue-400 font-medium transition-colors py-2"
                onClick={() => setIsOpen(false)}
              >
                AI Automation
              </Link>
              <Link 
                to="/smart-chatbots" 
                className="block text-white/90 hover:text-blue-400 font-medium transition-colors py-2"
                onClick={() => setIsOpen(false)}
              >
                Smart Chatbots
              </Link>
              <button 
                onClick={() => handleNavigation('how-it-works')}
                className="block text-white/90 hover:text-blue-400 font-medium transition-colors py-2"
              >
                How It Works
              </button>
              <button 
                onClick={() => handleNavigation('benefits')}
                className="block text-white/90 hover:text-blue-400 font-medium transition-colors py-2"
              >
                Benefits
              </button>
              <button 
                onClick={() => handleNavigation('contact')}
                className="block bg-blue-500 hover:bg-blue-600 text-white px-6 py-2.5 rounded-full transition-all duration-300 font-medium text-center mt-4 hover:shadow-[0_0_20px_rgba(59,130,246,0.5)] hover:scale-105"
              >
                Book a Consultation
              </button>
            </div>
          </div>
        </div>
      </div>
    </nav>
  );
};

export default Navbar;